@@ -46,10 +46,12 @@ from contextlib import contextmanager
 import msgpack
 import pylibmc
 
-VERSION = "0.6.2"
+VERSION = "0.6.3"
 LOCK_SH = 0
 LOCK_EX = 1
-CACHE_SOCKET = "/tmp/cache.starrydb"
+RUN_PATH = "/run/starrydb/"
+SERVER_ADDRESS = f"{RUN_PATH}address"
+CACHE_SOCKET = f"{RUN_PATH}cache.sock"
 
 class StarryError(Exception):
     '''StarryError'''
@@ -185,7 +187,10 @@ class StarryServer(object):
         self.depots = {}
         self.logger = StarryLog(log_file) if log_file is not None else None
         self.rw_ratio = rw_ratio
-        self.cache = None
+        self.memcached = None
+
+        pathlib.Path(RUN_PATH).mkdir(exist_ok=True)
+        pathlib.Path(SERVER_ADDRESS).write_bytes(msgpack.packb(address))
 
         if int(cache_size) > 0:
             try:
@@ -198,11 +203,11 @@ class StarryServer(object):
 
                 time.sleep(1)
 
-                self.cache = LibMemcachedClient(CACHE_SOCKET)
+                self.memcached = LibMemcachedClient(CACHE_SOCKET)
             except Exception as e:
                 self.logger.error(f"Caught exception: {e.__doc__}({e})")
 
-                self.cache = None
+                self.memcached = None
 
         if pathlib.Path(str(self.address)).is_socket():
             try:
@@ -214,16 +219,19 @@ class StarryServer(object):
             if "path" in depot:
                 depot_path = os.path.abspath(depot["path"])
 
-                self.depots[depot_path] = StarryDepot(depot_path, self.address, self.logger, self.rw_ratio, self.cursor, self.cache if depot.get("cache", False) is True else None)
+                self.depots[depot_path] = StarryDepot(depot_path, self.logger, self.rw_ratio, self.cursor, self.memcached)
+
+                if depot.get("cache", True) is False:
+                    self.depots[depot_path].disableCache()
 
                 self.cursor += 1
 
     def __del__(self):
         self.depots.clear()
 
-        if self.cache is not None:
+        if self.memcached is not None:
             try:
-                self.cache.flush_all()
+                self.memcached.flush_all()
             except:
                 pass
 
@@ -258,7 +266,7 @@ class StarryServer(object):
                         (depot, mode) = conn.recv()
 
                         if depot not in self.depots:
-                            self.depots[depot] = StarryDepot(depot, self.address, self.logger, self.rw_ratio, self.cursor)
+                            self.depots[depot] = StarryDepot(depot, self.logger, self.rw_ratio, self.cursor, self.memcached)
 
                             self.cursor += 1
 
@@ -272,12 +280,13 @@ class StarryServer(object):
                             pass
 
 class StarryDepot(object):
-    def __init__(self, path, server, logger, rw_ratio, index, cache=None):
+    def __init__(self, path, logger, rw_ratio, index, memcached):
         self.database = pathlib.Path(path)
         self.logger = logger
         self.rw_ratio = rw_ratio
         self.index = index
-        self.cache = cache
+        self.memcached = memcached
+        self.cache = memcached
         self.thread_cond = threading.Condition()
         self.thread_lock = threading.RLock()
         self.write_wait = 0
@@ -293,14 +302,6 @@ class StarryDepot(object):
 
             self.backup()
 
-        self.database.joinpath(".starrydb").write_bytes(msgpack.packb(server))
-
-    def __del__(self):
-        try:
-            self.database.joinpath(".starrydb").unlink()
-        except:
-            pass
-
     def executeCommand(self, conn, mode=LOCK_SH):
         if mode == LOCK_SH:
             while True:
@@ -351,6 +352,12 @@ class StarryDepot(object):
         except:
             pass
 
+    def enableCache(self):
+        self.cache = self.memcached
+
+    def disableCache(self):
+        self.cache = None
+
     def get(self, key):
         if type(key) is not list:
             key = [key]
@@ -1063,7 +1070,7 @@ class StarryDepot(object):
 class StarryClient(object):
     def __init__(self, path, mode=LOCK_SH, address=None):
         if address is None:
-            address = msgpack.unpackb(pathlib.Path(os.path.join(path, ".starrydb")).read_bytes(), use_list=False)
+            address = msgpack.unpackb(pathlib.Path(SERVER_ADDRESS).read_bytes(), use_list=False)
 
         self.client = multiprocessing.connection.Client(address, authkey=b'starry')
         self.client.send((os.path.abspath(path), mode))
